@@ -2,6 +2,9 @@ import datetime
 import decimal
 import sqlite3
 
+# Re-export some names from sqliteparser.
+from sqliteparser.ast import OnConflict, OnDelete, OnUpdate
+
 from .core import AddColumnMigration, AlterColumnMigration
 from .core import BooleanColumnStub as BooleanColumn
 from .core import (
